.. _whatsnew_152:

v1.5.2 (February 22, 2022)
==========================

Requirements
------------

* Add python 3.9 to test configuration (:ghpull:`122`)
* Set the upper bound on shapely to version 2.0 (not yet released).
  The shapely dependency may be dropped
  altogether in a future pvfactors release.  (:ghpull:`130`)


Fixes
-----

* A small bug in the pvlib-python implementation of the Perez transposition model was
  discovered and fixed in pvlib v0.9.0.  To ensure the error does not affect pvfactors
  output moving forward, the pvlib dependency is updated from ``pvlib>=0.7.0,<0.9.0`` to
  ``pvlib>=0.9.0,<0.10.0``.  This will likely change the results of irradiance simulations.
  According to the
  `pvlib release notes <https://pvlib-python.readthedocs.io/en/v0.9.0/whatsnew.html#bug-fixes>`_,
  the differences are "expected to be small and primarily occur at low irradiance conditions".
  (:ghpull:`121`)
* Fixed a bug that affected some irradiance simulations when `surface_tilt` is exactly zero.
  See `GH #125 <https://github.com/SunPower/pvfactors/issues/125>`_ for details. (:ghpull:`128`)

Maintenance
-----------

* Update CI including sphinx for documentation (:ghpull:`124`)
* Add documentation for making new releases (:ghpull:`133`)

Contributors
------------
* Kevin Anderson (:ghuser:`kanderso-nrel`)
* Marc Anoma (:ghuser:`anomam`)
* Mark Campanelli (:ghuser:`campanelli-sunpower`)
